@@ -1,6 +1,7 @@
 import logging
 from pathlib import Path
 import typing as t
+import os
 
 from rich.logging import RichHandler
 from rich import print
@@ -14,7 +15,8 @@ app = typer.Typer(rich_markup_mode="markdown")
 
 
 def version_callback(value: bool):
-    version = tomli.loads(Path("../pyproject.toml").read_text(encoding="utf-8"))["tool"]["poetry"]["version"]
+    path = os.path.abspath(os.path.join(os.path.dirname(__file__),".."))
+    version = tomli.loads(Path(f"{path}/pyproject.toml").read_text(encoding="utf-8"))["tool"]["poetry"]["version"]
     if value:
         print(f":speech_balloon: h-cli Version: {version}")
         raise typer.Exit()
